@@ -1,11 +1,12 @@
 # @useDynLib dual, .registration = TRUE
+
 #' @importFrom methods is new
 #' @importFrom stats dnorm pchisq pnorm
-#'
+
+"_PACKAGE"
+
 #' @name dual-package
-#' 
-#' @docType package
-#' 
+#'
 #' @encoding UTF-8
 #' 
 #' @title
@@ -25,8 +26,8 @@
 #' \tabular{ll}{
 #' Package: \tab dual\cr
 #' Type: \tab Package\cr
-#' Version: \tab 0.0.5\cr
-#' Date: \tab 2023-10-02\cr
+#' Version: \tab 0.0.6\cr
+#' Date: \tab 2025-05-27\cr
 #' License: \tab GPL-3\cr
 #' }
 #' 
